package w3.ex3.period.ex;

import java.util.Date;

/**
 * @@invariant @getStart()@ is before or at the same time as @getEnd()@
 * @@invariant @getStart()@ consistently returns the same value after object
 *             creation
 * @@invariant @getEnd()@ consistently returns the same value after object
 *             creation
 */
public final class Period {
	private final Date start;
	private final Date end;

	/**
	 * @@param @start@ the beginning of the period
	 * @@param @end@ the end of the period; must not precede @start@
	 * @@pre @start@ <= @end@
	 * @@post The time span of the returned period is positive.
	 * @@throws @IllegalArgumentException@ if @start@ is after @end@
	 * @@throws @NullPointerException@ if @start@ or @end@ is @null@
	 */
	public Period(Date start, Date end) {
		if (start.compareTo(end) > 0) {
			throw new IllegalArgumentException(start + " after " + end);
		}
		this.start = start;
		this.end = end;
	}

	public Date getStart() {
		return start;
	}

	public Date getEnd() {
		return end;
	}
}
